@@ -22,7 +22,7 @@ extern GtkWidget* GBLmainWindow;
 #if GTK_MINOR_VERSION >= 6
 
 static const char* 
-GBLprogramName = "ISO Master 1.2";
+GBLprogramName = "ISO Master "VERSION;
 
 static const char* 
 GBLauthors[2] = {
@@ -80,26 +80,26 @@ GBLauthors[2] = {
 "\n"
 "David Johnson\n"
 "http://www.david-web.co.uk/\n"
-"- Debian packages of ISO Master, versions 0.1 - 1.0\n"
+"- Debian packages of ISO Master, versions 0.1 - 1.2\n"
 "- Nexenta GNU/OpenSolaris package of ISO Master, version 1.0\n"
 "\n"
 "Marcin Zajaczkowski\n"
 "http://timeoff.wsisiz.edu.pl/rpms.html\n"
-"- Fedora packages of ISO Master, versions 0.3 - 1.1\n"
+"- Fedora packages of ISO Master, versions 0.3 - 1.2\n"
 "\n"
 "Toni Graffy\n"
 "Maintainer of many SuSE packages at PackMan\n"
-"- SuSE packages of ISO Master, versions 0.4 - 1.1\n"
+"- SuSE packages of ISO Master, versions 0.4 - 1.2\n"
 "\n"
 "Maciej Libuda\n"
-"- Arch packages of ISO Master, versions 0.3 - 1.1\n"
+"- Arch packages of ISO Master, versions 0.3 - 1.2\n"
 "\n"
 "GuestToo\n"
 "- Puppy packages of ISO Master, versions 0.1, 0.4 - 1.0\n"
 "\n"
 "vktgz\n"
 "http://www.vktgz.homelinux.net/\n"
-"- Gentoo ebuilds of ISO Master, versions 0.4 - 1.1\n"
+"- Gentoo ebuilds of ISO Master, versions 0.4 - 1.2\n"
 "\n"
 "Babak Farrokhi\n"
 "- FreeBSD ports package of ISO Master, versions 0.6 - 1.1\n"
@@ -109,30 +109,30 @@ GBLauthors[2] = {
 "- Slackware packages of ISO Master, versions 0.4 - 0.5\n"
 "\n"
 "Michael Shigorin\n"
-"- Alt packages of ISO Master, versions 0.5, 0.7\n"
+"- Alt packages of ISO Master, versions 0.5, 0.7, 1.2\n"
 "\n"
 "Rene Eric\n"
-"SLAX packages of versions 0.7 - 1.0\n"
+"SLAX packages of versions 0.7 - 1.2\n"
 "\n"
 "Adam Williamson\n"
 "http://www.happyassassin.net/\n"
-"- Mandriva package of ISO Master, versions 0.8 - 1.0\n"
+"- Mandriva package of ISO Master, versions 0.8 - 1.2\n"
 "\n"
 "Matias A. Fonzo\n"
-"- Slackware package of ISO Master, versions 0.8 - 1.0\n"
+"- Slackware package of ISO Master, versions 0.8 - 1.2\n"
 "\n"
 "Giovanni Bechis\n"
 "http://www.snb.it/\n"
-"- OpenBSD ports package of ISO Master, versions 1.0 - 1.1\n"
+"- OpenBSD port of ISO Master, versions 1.0 - 1.2\n"
 "\n"
 "Pierrick Le Brun\n"
-"- Zenwalk package of ISO Master, versions 1.0 - 1.1\n"
+"- Zenwalk package of ISO Master, versions 1.0 - 1.2\n"
 "\n"
-"Muggins\n"
-"- Puppy package of ISO Master, version 1.1\n"
+"Todd (muggins)\n"
+"- Puppy package of ISO Master, versions 1.1 - 1.2\n"
 "\n"
-"Todd\n"
-"- Puppy package of ISO Master, version 1.1\n"
+"Kenan Pelit\n"
+"- Pardus package of ISO Master, version 1.2\n"
 "\n"
 "F. Lombardi\n"
 "SLAX package of ISO Master, version 0.7\n"
@@ -149,8 +149,11 @@ NULL};
 
 static const char* 
 GBLtranslators = 
+"Ihar Hrachyshka\n"
+"- be (Belarusian) translation of ISO Master version 1.3\n"
+"\n"
 "Dessislav Petrov\n"
-"- bg (Bulgarian) translation of ISO Master versions 0.6 - 1.1\n"
+"- bg (Bulgarian) translation of ISO Master versions 0.6 - 1.3\n"
 "\n"
 "Rafael Carreras\n"
 "- ca (Catalan) translation of ISO Master version 1.1\n"
@@ -158,17 +161,23 @@ GBLtranslators =
 "Schmaki\n"
 "- cs (Czech) translation of ISO Master version 1.1\n"
 "\n"
+"Jiri Huf\n"
+"- cs (Czech) translation of ISO Master version 1.3\n"
+"\n"
 "Toni Graffy\n"
-"- de (German) translation of ISO Master versions 0.6 - 1.1\n"
+"- de (German) translation of ISO Master versions 0.6 - 1.3\n"
 "\n"
 "Mike Kranidis\n"
-"- el (Greek) translation of ISO Master version 1.1\n"
+"- el (Greek) translation of ISO Master versions 1.1 - 1.3\n"
 "\n"
 "Juan Garcia-Murga Monago\n"
-"- es (Spanish) translation of ISO Master version 0.7 - 1.1\n"
+"- es (Spanish) translation of ISO Master versions 0.7 - 1.1\n"
+"\n"
+"Edmund Laugasson\n"
+"- et (Estonian) translation of ISO Master version 1.3\n"
 "\n"
 "Eero Salokannel\n"
-"- fi (Finnish) translation of ISO Master version 1.1\n"
+"- fi (Finnish) translation of ISO Master versions 1.1 - 1.3\n"
 "\n"
 "Magnus Valle\n"
 "- fo (Faroese) translation of ISO Master version 1.1\n"
@@ -180,10 +189,19 @@ GBLtranslators =
 "- fr (French) translation of ISO Master version 0.7\n"
 "\n"
 "Bruno Bord\n"
-"- fr (French) translation of ISO Master versions 0.8 - 1.1\n"
+"- fr (French) translation of ISO Master versions 0.8 - 1.3\n"
+"\n"
+"Fima Kachinski\n"
+"- he (Hebrew) translation of ISO Master version 1.3\n"
 "\n"
 "Ante Karamatic\n"
-" - hr (Croatian) translation of ISO Master version 1.0\n"
+"- hr (Croatian) translation of ISO Master version 1.0\n"
+"\n"
+"Andras Horvath\n"
+"- hu (Hungarian) translation of ISO Master version 1.3\n"
+"\n"
+"Wahyu Puji L\n"
+"- id (Indonesian) translation of ISO Master version 1.3\n"
 "\n"
 "F. Lombardi\n"
 "- it (Italian) translation of ISO Master version 0.7 - 1.0\n"
@@ -195,13 +213,13 @@ GBLtranslators =
 "- nb (Norwegian Bokmal) translation of ISO Master version 1.0\n"
 "\n"
 "Stephen Brandt\n"
-"- nl (Dutch) translation of ISO Master version 0.7 - 1.0\n"
+"- nl (Dutch) translation of ISO Master versions 0.7 - 1.3\n"
 "\n"
 "Robert Groenning\n"
 "- nn (Norwegian Nynorsk) translation of ISO Master version 1.1\n"
 "\n"
-"Marciej Libuda\n"
-"- pl (Polish) translation of ISO Master versions 0.6 - 1.1\n"
+"Maciej Libuda\n"
+"- pl (Polish) translation of ISO Master versions 0.6 - 1.3\n"
 "\n"
 "Joao de Ferro\n"
 "- pt (Portuguese) translation of ISO Master version 0.8, 1.0\n"
@@ -210,16 +228,16 @@ GBLtranslators =
 "- ro (Romanian) translation of ISO Master version 0.7 - 0.8, 1.0\n"
 "\n"
 "Anton Obidin\n"
-"- ru (Russian) translation of ISO Master versions 0.6 - 1.0\n"
+"- ru (Russian) translation of ISO Master versions 0.6 - 1.3\n"
 "\n"
 "Jozef Riha\n"
-"- sk (Slovak) translation of ISO Master version 1.0\n"
+"- sk (Slovak) translation of ISO Master versions 1.0 - 1.3\n"
 "\n"
 "Uros Golob\n"
-"- sl (Slovenian) translation of ISO Master version 1.1\n"
+"- sl (Slovenian) translation of ISO Master versions 1.1 - 1.3\n"
 "\n"
 "Besnik Bleta\n"
-"- sq (Albanian) translation of ISO Master versions 0.8 - 1.1\n"
+"- sq (Albanian) translation of ISO Master versions 0.8 - 1.3\n"
 "\n"
 "Danijel Muharemovic\n"
 "- sr (Serbian) translation of ISO Master version 1.1\n"
@@ -237,20 +255,20 @@ GBLtranslators =
 "- tr (Turkish) translation of ISO Master version 1.0\n"
 "\n"
 "Serhey Kusyumoff\n"
-"- uk (Ukrainian) translation of ISO Master version 0.8\n"
+"- uk (Ukrainian) translation of ISO Master versions 0.8, 1.3\n"
 "\n"
 "Sun Minchao\n"
-"- zh_CN (Simplified Chineese) translation of ISO Master version 0.7 - 1.1\n"
+"- zh_CN (Simplified Chineese) translation of ISO Master version 0.7 - 1.3\n"
 "\n"
 "Cheng-Wei Chien\n"
-"- zh_TW (Chineese/Taiwan) translation of ISO Master version 0.6 - 1.1\n";
+"- zh_TW (Chineese/Taiwan) translation of ISO Master version 0.6 - 1.3\n";
 
 static const char* 
 GBLcomments = "An application for editing ISO9660 images based on the "
               "bkisofs access library and the GTK2 GUI toolkit.";
 
 static const char* 
-GBLcopyright = "Copyright 2005-2007 Andrew Smith";
+GBLcopyright = "Copyright 2005-2008 Andrew Smith";
 
 static const char* 
 GBLwebsite = "http://littlesvr.ca/isomaster/";
@@ -269,8 +287,8 @@ N_(
 " - The top file browser shows files and directories on your machine.\n"
 " - The bottom file browser shows files and directories on the ISO image.\n"
 "\n"
-"To open an existing ISO file click on 'Image' and 'Open'. To create a new\n"
-"ISO file click on 'Image' and 'New'.\n"
+"To open an existing ISO file click on 'File' and 'Open'. To create a new\n"
+"ISO file click on 'File' and 'New'.\n"
 "\n"
 "To add one or more files or directories to the ISO select them in the top\n"
 "file browser and click the 'Add to the ISO' button in the middle toolbar.\n"
@@ -285,7 +303,7 @@ N_(
 "If you select something in the bottom file browser and right-click on it,\n"
 "there are several more options available.\n"
 "\n"
-"Once you made all the changes to the new ISO image, click on 'Image' and\n"
+"Once you made all the changes to the new ISO image, click on 'File' and\n"
 "'Save As'. You cannot overwrite the original ISO.\n"
 );
 
